summaryrefslogtreecommitdiffstats
path: root/lib/compatibility/knewstuff/entry.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/compatibility/knewstuff/entry.h')
-rw-r--r--lib/compatibility/knewstuff/entry.h86
1 files changed, 43 insertions, 43 deletions
diff --git a/lib/compatibility/knewstuff/entry.h b/lib/compatibility/knewstuff/entry.h
index 3a16964d..a3c816a1 100644
--- a/lib/compatibility/knewstuff/entry.h
+++ b/lib/compatibility/knewstuff/entry.h
@@ -20,11 +20,11 @@
#ifndef KNEWSTUFF_ENTRY_H
#define KNEWSTUFF_ENTRY_H
-#include <qdatetime.h>
-#include <qdom.h>
-#include <qmap.h>
-#include <qstring.h>
-#include <qstringlist.h>
+#include <tqdatetime.h>
+#include <tqdom.h>
+#include <tqmap.h>
+#include <tqstring.h>
+#include <tqstringlist.h>
#include <kurl.h>
@@ -48,7 +48,7 @@ class KDE_EXPORT Entry
/**
* Constructor.
*/
- Entry( const QDomElement & );
+ Entry( const TQDomElement & );
/**
* Destructor.
@@ -58,75 +58,75 @@ class KDE_EXPORT Entry
/**
* Sets the (unique) name for this data object.
*/
- void setName( const QString & );
+ void setName( const TQString & );
/**
* Retrieve the name of the data object.
*
* @return object name
*/
- QString name() const;
+ TQString name() const;
/**
* Sets the application type, e.g. 'kdesktop/wallpaper'.
*/
- void setType( const QString & );
+ void setType( const TQString & );
/**
* Retrieve the type of the data object.
*
* @return object type
*/
- QString type() const;
+ TQString type() const;
/**
* Sets the full name of the object's author.
*/
- void setAuthor( const QString & );
+ void setAuthor( const TQString & );
/**
* Retrieve the author's name of the object.
*
* @return object author
*/
- QString author() const;
+ TQString author() const;
/**
* Sets the license (abbreviation) applicable to the object.
*/
- void setLicence( const QString & );
+ void setLicence( const TQString & );
/**
* Retrieve the license name of the object.
*
* @return object license
*/
- QString license() const;
+ TQString license() const;
/**
* Sets a short description on what the object is all about.
*/
- void setSummary( const QString &, const QString &lang = QString::null );
+ void setSummary( const TQString &, const TQString &lang = TQString::null );
/**
* Retrieve a short description about the object.
*
* @param lang preferred language, or QString::null for KDE default
* @return object description
*/
- QString summary( const QString &lang = QString::null ) const;
+ TQString summary( const TQString &lang = TQString::null ) const;
/**
* Sets the version number.
*/
- void setVersion( const QString & );
+ void setVersion( const TQString & );
/**
* Retrieve the version string of the object.
*
* @return object version
*/
- QString version() const;
+ TQString version() const;
/**
* Sets the release number, which is increased for feature-equal objects
@@ -144,41 +144,41 @@ class KDE_EXPORT Entry
/**
* Sets the release date.
*/
- void setReleaseDate( const QDate & );
+ void setReleaseDate( const TQDate & );
/**
* Retrieve the date of the object's publication.
*
* @return object release date
*/
- QDate releaseDate() const;
+ TQDate releaseDate() const;
/**
* Sets the object's file.
*/
- void setPayload( const KURL &, const QString &lang = QString::null );
+ void setPayload( const KURL &, const TQString &lang = TQString::null );
/**
* Retrieve the file name of the object.
*
* @param lang preferred language, or QString::null for KDE default
* @return object filename
*/
- KURL payload( const QString &lang = QString::null ) const;
+ KURL payload( const TQString &lang = TQString::null ) const;
/**
* Sets the object's preview file, if available. This should be a
* picture file.
*/
- void setPreview( const KURL &, const QString &lang = QString::null );
+ void setPreview( const KURL &, const TQString &lang = TQString::null );
/**
* Retrieve the file name of an image containing a preview of the object.
*
* @param lang preferred language, or QString::null for KDE default
* @return object preview filename
*/
- KURL preview( const QString &lang = QString::null ) const;
+ KURL preview( const TQString &lang = TQString::null ) const;
/**
* Sets the rating between 0 (worst) and 10 (best).
@@ -214,42 +214,42 @@ class KDE_EXPORT Entry
* Return the full name for the meta information. It is constructed as
* name-version-release.
*/
- QString fullName();
+ TQString fullName();
/**
* Return the list of languages this object supports.
*/
- QStringList langs();
+ TQStringList langs();
/**
* @internal
*/
- void parseDomElement( const QDomElement & );
+ void parseDomElement( const TQDomElement & );
/**
* @internal
*/
- QDomElement createDomElement( QDomDocument &, QDomElement &parent );
+ TQDomElement createDomElement( TQDomDocument &, TQDomElement &parent );
protected:
- QDomElement addElement( QDomDocument &doc, QDomElement &parent,
- const QString &tag, const QString &value );
+ TQDomElement addElement( TQDomDocument &doc, TQDomElement &parent,
+ const TQString &tag, const TQString &value );
private:
- QString mName;
- QString mType;
- QString mAuthor;
- QString mLicence;
- QMap<QString,QString> mSummaryMap;
- QString mVersion;
+ TQString mName;
+ TQString mType;
+ TQString mAuthor;
+ TQString mLicence;
+ TQMap<TQString,TQString> mSummaryMap;
+ TQString mVersion;
int mRelease;
- QDate mReleaseDate;
- QMap<QString,KURL> mPayloadMap;
- QMap<QString,KURL> mPreviewMap;
+ TQDate mReleaseDate;
+ TQMap<TQString,KURL> mPayloadMap;
+ TQMap<TQString,KURL> mPreviewMap;
int mRating;
int mDownloads;
- QStringList mLangs;
+ TQStringList mLangs;
};
}
@@ -58,75 +58,75 @@ class KDE_EXPORT Entry
* Retrieve a short description about the object.
*
- * @param lang preferred language, or QString::null for KDE default
+ * @param lang preferred language, or TQString::null for KDE default
* @return object description
*/
@@ -144,41 +144,41 @@ class KDE_EXPORT Entry
* Retrieve the file name of the object.
*
- * @param lang preferred language, or QString::null for KDE default
+ * @param lang preferred language, or TQString::null for KDE default
* @return object filename
*/
@@ -144,41 +144,41 @@ class KDE_EXPORT Entry
* Retrieve the file name of an image containing a preview of the object.
*
- * @param lang preferred language, or QString::null for KDE default
+ * @param lang preferred language, or TQString::null for KDE default
* @return object preview filename
*/